@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,8 +32,9 @@
 #define __NAUTILUS_ACTIONS_API_NA_GCONF_UTILS_H__
 
 /**
- * SECTION: na_gconf_utils
- * @short_description: GConf utilities.
+ * SECTION: gconf-utils
+ * @title: GConf Misc
+ * @short_description: The GConf Library Utilities
  * @include: runtime/na-gconf-utils.h
  */
 
@@ -64,7 +65,7 @@ gboolean na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path
 
 gboolean na_gconf_utils_remove_entry     ( GConfClient *gconf, const gchar *path, gchar **message );
 
-GSList  *na_gconf_utils_slist_from_string( const gchar *string );
+GSList  *na_gconf_utils_slist_from_string( const gchar *value );
 gchar   *na_gconf_utils_slist_to_string  ( GSList *slist );
 
 G_END_DECLS
