@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,20 +32,49 @@
 #define __NAUTILUS_ACTIONS_API_NA_IFACTORY_OBJECT_H__
 
 /**
- * SECTION: na_ifactory_object
- * @short_description: #NAIFactoryObject interface definition.
+ * SECTION: ifactory-object
+ * @title: NAIFactoryObject
+ * @short_description: The #NAObjectItem Interface v 1
  * @include: nautilus-actions/na-ifactory_object.h
  *
- * This interface must be implemented by #NAObject-derived objects which
- * should take advantage of data factory management system.
+ * This interface is implemented by #NAObjectItem derived objects so that they
+ * can take advantage of our data factory management system.
  *
- * A #NAObject-derived which should implement this #NAIFactoryObject
+ * A #NAObjectItem derived object which would implement this #NAIFactoryObject
  * interface must meet following conditions:
- * - must accept an empty constructor
+ * <itemizedlist>
+ *   <listitem>
+ *     <para>
+ *       accept an empty constructor
+ *     </para>
+ *   </listitem>
+ * </itemizedlist>
  *
- * Elementary data are implemented as a GList of NADataBoxed objects.
- *
- * Nautilus-Actions v 2.30 - API version:  1
+ * <refsect2>
+ *  <title>Versions historic</title>
+ *  <table>
+ *    <title>Historic of the versions of the #NAIFactoryObject interface</title>
+ *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
+ *      <colspec colname="na-version" />
+ *      <colspec colname="api-version" />
+ *      <colspec colname="current" />
+ *      <thead>
+ *        <row>
+ *          <entry>&prodname; version</entry>
+ *          <entry>#NAIFactoryObject interface version</entry>
+ *          <entry></entry>
+ *        </row>
+ *      </thead>
+ *      <tbody>
+ *        <row>
+ *          <entry>since 2.30</entry>
+ *          <entry>1</entry>
+ *          <entry>current version</entry>
+ *        </row>
+ *      </tbody>
+ *    </tgroup>
+ *  </table>
+ * </refsect2>
  */
 
 #include "na-data-def.h"
@@ -59,21 +88,41 @@ G_BEGIN_DECLS
 #define NA_IS_IFACTORY_OBJECT( instance )				( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_IFACTORY_OBJECT_TYPE ))
 #define NA_IFACTORY_OBJECT_GET_INTERFACE( instance )	( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_IFACTORY_OBJECT_TYPE, NAIFactoryObjectInterface ))
 
-typedef struct NAIFactoryObject                 NAIFactoryObject;
+typedef struct _NAIFactoryObject                 NAIFactoryObject;
 
-typedef struct NAIFactoryObjectInterfacePrivate NAIFactoryObjectInterfacePrivate;
+typedef struct _NAIFactoryObjectInterfacePrivate NAIFactoryObjectInterfacePrivate;
 
+/**
+ * NAIFactoryObjectInterface:
+ * @get_version: returns the version of this interface the NAObjectItem implements.
+ * @get_groups:  returns a pointer to the NADataGroup which defines this object.
+ * @copy:        post copy callback.
+ * @are_equal:   tests if two NAObjectItem are equals.
+ * @is_valid:    tests if one NAObjectItem is valid.
+ * @read_start:  triggered before serializing a NAObjectItem.
+ * @read_done:   triggered after a NAObjectItem has been serialized.
+ * @write_start: triggered before unserializing a NAObjectItem.
+ * @write_done:  triggered after a NAObjectItem has been unserialized.
+ *
+ * In order to take full advantage of our data managament system,
+ * NAObjectItem-derived objects all implement this #NAIFactoryObject
+ * interface.
+ */
 typedef struct {
+	/*< private >*/
 	GTypeInterface                    parent;
 	NAIFactoryObjectInterfacePrivate *private;
 
+	/*< public >*/
 	/**
 	 * get_version:
 	 * @instance: this #NAIFactoryObject instance.
 	 *
+	 * Defaults to 1.
+	 *
 	 * Returns: the version of this interface supported by @instance implementation.
 	 *
-	 * Defaults to 1.
+	 * Since: 2.30
 	 */
 	guint         ( *get_version )( const NAIFactoryObject *instance );
 
@@ -82,6 +131,8 @@ typedef struct {
 	 * @instance: this #NAIFactoryObject instance.
 	 *
 	 * Returns: a pointer to the NADataGroup which defines this object.
+	 *
+	 * Since: 2.30
 	 */
 	NADataGroup * ( *get_groups ) ( const NAIFactoryObject *instance );
 
@@ -93,6 +144,8 @@ typedef struct {
 	 * This function is triggered after having copied @source to
 	 * @instance target. This later may take advantage of this call
 	 * to do some particular copy tasks.
+	 *
+	 * Since: 2.30
 	 */
 	void          ( *copy )       ( NAIFactoryObject *instance, const NAIFactoryObject *source );
 
@@ -101,10 +154,12 @@ typedef struct {
 	 * @a: the first #NAIFactoryObject instance.
 	 * @b: the second #NAIFactoryObject instance.
 	 *
-	 * Returns: %TRUE if @a is equal to @b.
-	 *
 	 * This function is triggered after all elementary data comparisons
 	 * have been sucessfully made.
+	 *
+	 * Returns: %TRUE if @a is equal to @b.
+	 *
+	 * Since: 2.30
 	 */
 	gboolean      ( *are_equal )  ( const NAIFactoryObject *a, const NAIFactoryObject *b );
 
@@ -112,10 +167,12 @@ typedef struct {
 	 * is_valid:
 	 * @object: the #NAIFactoryObject instance whose validity is to be checked.
 	 *
-	 * Returns: %TRUE if @object is valid.
-	 *
 	 * This function is triggered after all elementary data comparisons
 	 * have been sucessfully made.
+	 *
+	 * Returns: %TRUE if @object is valid.
+	 *
+	 * Since: 2.30
 	 */
 	gboolean      ( *is_valid )   ( const NAIFactoryObject *object );
 
@@ -128,6 +185,8 @@ typedef struct {
 	 *  may append messages to this list, but shouldn't reinitialize it.
 	 *
 	 * Called just before the object is unserialized.
+	 *
+	 * Since: 2.30
 	 */
 	void          ( *read_start ) ( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 
@@ -140,6 +199,8 @@ typedef struct {
 	 *  may append messages to this list, but shouldn't reinitialize it.
 	 *
 	 * Called when the object has been unserialized.
+	 *
+	 * Since: 2.30
 	 */
 	void          ( *read_done )  ( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 
@@ -154,6 +215,8 @@ typedef struct {
 	 * Called just before the object is serialized.
 	 *
 	 * Returns: a NAIIOProvider operation return code.
+	 *
+	 * Since: 2.30
 	 */
 	guint         ( *write_start )( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
@@ -168,6 +231,8 @@ typedef struct {
 	 * Called when the object has been serialized.
 	 *
 	 * Returns: a NAIIOProvider operation return code.
+	 *
+	 * Since: 2.30
 	 */
 	guint         ( *write_done ) ( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 }
@@ -175,10 +240,10 @@ typedef struct {
 
 GType        na_ifactory_object_get_type( void );
 
-NADataGroup *na_ifactory_object_get_data_groups( const NAIFactoryObject *object );
-
 NADataBoxed *na_ifactory_object_get_data_boxed ( const NAIFactoryObject *object, const gchar *name );
 
+NADataGroup *na_ifactory_object_get_data_groups( const NAIFactoryObject *object );
+
 void        *na_ifactory_object_get_as_void    ( const NAIFactoryObject *object, const gchar *name );
 
 void         na_ifactory_object_set_from_void  ( NAIFactoryObject *object, const gchar *name, const void *data );
