@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -46,13 +46,13 @@
 
 /* private class data
  */
-struct NAImporterAskClassPrivate {
+struct _NAImporterAskClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAImporterAskPrivate {
+struct _NAImporterAskPrivate {
 	gboolean                dispose_has_run;
 	GtkBuilder             *builder;
 	GtkWindow              *toplevel;
@@ -222,7 +222,7 @@ import_ask_new()
 	return( g_object_new( NA_IMPORTER_ASK_TYPE, NULL ));
 }
 
-/**
+/*
  * na_importer_ask_user:
  * @importing: the #NAObjectItem-derived object being currently imported.
  * @existing: the #NAObjectItem-derived already existing object with the same ID.
@@ -270,7 +270,7 @@ na_importer_ask_user( const NAObjectItem *importing, const NAObjectItem *existin
 
 		mode = dialog->private->mode;
 
-		gtk_widget_hide_all( GTK_WIDGET( dialog->private->toplevel ));
+		gtk_widget_hide( GTK_WIDGET( dialog->private->toplevel ));
 		gtk_widget_destroy( GTK_WIDGET( dialog->private->toplevel ));
 
 	} else {
