@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,13 +31,16 @@
 #ifndef __CORE_NA_IO_PROVIDER_H__
 #define __CORE_NA_IO_PROVIDER_H__
 
-/**
- * SECTION: na_io_provider
- * @short_description: #NAIOProvider class definition.
+/* @title: NAIIOProvider
+ * @short_description: The #NAIOProvider Class Definition.
  * @include: core/na-io-provider.h
  *
  * NAIOProvider is the Nautilus-Actions class which is used to manage
- * external I/O Providers which implement NAIIOProvider interface.
+ * external I/O Providers which implement #NAIIOProvider interface.
+ *
+ * Internal Nautilus-Actions code should never directly call a
+ * #NAIIOProvider interface method, but rather should call the
+ * corresponding NAIOProvider class method.
  */
 
 #include "na-iprefs.h"
@@ -45,24 +48,26 @@
 
 G_BEGIN_DECLS
 
-#define NA_IO_PROVIDER_TYPE					( na_io_provider_get_type())
-#define NA_IO_PROVIDER( object )			( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IO_PROVIDER_TYPE, NAIOProvider ))
-#define NA_IO_PROVIDER_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NA_IO_PROVIDER_TYPE, NAIOProviderClass ))
-#define NA_IS_IO_PROVIDER( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IO_PROVIDER_TYPE ))
-#define NA_IS_IO_PROVIDER_CLASS( klass )	( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_IO_PROVIDER_TYPE ))
-#define NA_IO_PROVIDER_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_IO_PROVIDER_TYPE, NAIOProviderClass ))
+#define NA_IO_PROVIDER_TYPE                 ( na_io_provider_get_type())
+#define NA_IO_PROVIDER( object )            ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IO_PROVIDER_TYPE, NAIOProvider ))
+#define NA_IO_PROVIDER_CLASS( klass )       ( G_TYPE_CHECK_CLASS_CAST( klass, NA_IO_PROVIDER_TYPE, NAIOProviderClass ))
+#define NA_IS_IO_PROVIDER( object )         ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IO_PROVIDER_TYPE ))
+#define NA_IS_IO_PROVIDER_CLASS( klass )    ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_IO_PROVIDER_TYPE ))
+#define NA_IO_PROVIDER_GET_CLASS( object )  ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_IO_PROVIDER_TYPE, NAIOProviderClass ))
 
-typedef struct NAIOProviderPrivate      NAIOProviderPrivate;
+typedef struct _NAIOProviderPrivate      NAIOProviderPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObject              parent;
 	NAIOProviderPrivate *private;
 }
 	NAIOProvider;
 
-typedef struct NAIOProviderClassPrivate NAIOProviderClassPrivate;
+typedef struct _NAIOProviderClassPrivate NAIOProviderClassPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObjectClass              parent;
 	NAIOProviderClassPrivate *private;
 }
