@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,21 +32,24 @@
 #include <config.h>
 #endif
 
+#include <stdlib.h>
 #include <string.h>
 #include <uuid/uuid.h>
 
 #include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
+#include "na-io-provider.h"
+
 /* private class data
  */
-struct NAObjectItemClassPrivate {
+struct _NAObjectItemClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAObjectItemPrivate {
+struct _NAObjectItemPrivate {
 	gboolean   dispose_has_run;
 
 	void      *provider_data;
@@ -72,7 +75,6 @@ static void   object_copy( NAObject*target, const NAObject *source, gboolean rec
 static gchar *object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent );
 
 static void   copy_children( NAObjectItem *target, const NAObjectItem *source );
-static void   rebuild_children_slist( NAObjectItem *item );
 
 GType
 na_object_item_get_type( void )
@@ -145,13 +147,13 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "na_object_item_instance_init";
 	NAObjectItem *self;
 
-	g_debug( "%s: instance=%p (%s), klass=%p",
-			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-
 	g_return_if_fail( NA_IS_OBJECT_ITEM( instance ));
 
 	self = NA_OBJECT_ITEM( instance );
 
+	g_debug( "%s: instance=%p (%s), klass=%p",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
+
 	self->private = g_new0( NAObjectItemPrivate, 1 );
 }
 
@@ -162,14 +164,14 @@ instance_dispose( GObject *object )
 	NAObjectItem *self;
 	GList *children;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 	g_return_if_fail( NA_IS_OBJECT_ITEM( object ));
 
 	self = NA_OBJECT_ITEM( object );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 		self->private->dispose_has_run = TRUE;
 
 		children = na_object_get_items( self );
@@ -204,6 +206,9 @@ instance_finalize( GObject *object )
 static void
 object_copy( NAObject *target, const NAObject *source, gboolean recursive )
 {
+	static const gchar *thisfn = "na_object_item_object_copy";
+	void *provider;
+
 	g_return_if_fail( NA_IS_OBJECT_ITEM( target ));
 	g_return_if_fail( NA_IS_OBJECT_ITEM( source ));
 
@@ -213,6 +218,20 @@ object_copy( NAObject *target, const NAObject *source, gboolean recursive )
 		if( recursive ){
 			copy_children( NA_OBJECT_ITEM( target ), NA_OBJECT_ITEM( source ));
 		}
+
+		provider = na_object_get_provider( source );
+
+		if( provider ){
+			if( !NA_IS_IO_PROVIDER( provider )){
+				g_warning( "%s: source=%p (%s), provider=%p is not a NAIOProvider",
+						thisfn,
+						( void * ) source, G_OBJECT_TYPE_NAME( source ),
+						( void * ) provider );
+
+			} else {
+				na_io_provider_duplicate_data( NA_IO_PROVIDER( provider ), NA_OBJECT_ITEM( target ), NA_OBJECT_ITEM( source ), NULL );
+			}
+		}
 	}
 }
 
@@ -224,7 +243,7 @@ object_copy( NAObject *target, const NAObject *source, gboolean recursive )
 static gchar *
 object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent )
 {
-	GList *childs, *it;
+	GList *children, *it;
 	uuid_t uuid;
 	gchar uuid_str[64];
 	gchar *new_uuid = NULL;
@@ -233,11 +252,11 @@ object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent )
 
 	if( !NA_OBJECT_ITEM( item )->private->dispose_has_run ){
 
-		/* recurse into NAObjectItems childs
+		/* recurse into NAObjectItems children
 		 * i.e., if a menu, recurse into embedded actions
 		 */
-		childs = na_object_get_items( item );
-		for( it = childs ; it ; it = it->next ){
+		children = na_object_get_items( item );
+		for( it = children ; it ; it = it->next ){
 			na_object_set_new_id( it->data, new_parent );
 		}
 
@@ -254,8 +273,6 @@ object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent )
  * @a: the first (original) #NAObjectItem instance.
  * @b: the second #NAObjectItem instance.
  *
- * Returns: %TRUE if @a is equal to @b.
- *
  * This function participates to the #na_iduplicable_check_status() stack,
  * and is triggered after all comparable elementary data (in #NAIFactoryObject
  * sense) have already been successfully compared.
@@ -265,6 +282,10 @@ object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent )
  *
  * Note that, when called from na_object_check_status, the status of children
  * have already been checked, and so we should be able to rely on them.
+ *
+ * Returns: %TRUE if @a is equal to @b.
+ *
+ * Since: 2.30
  */
 gboolean
 na_object_item_are_equal( const NAObjectItem *a, const NAObjectItem *b )
@@ -370,10 +391,12 @@ na_object_item_are_equal( const NAObjectItem *a, const NAObjectItem *b )
  * @item: the #NAObjectItem from which we want retrieve a subitem.
  * @id: the id of the searched subitem.
  *
- * Returns: a pointer to the #NAObjectId-derived child with the required id.
+ * Returns: a pointer to the #NAObjectId -derived child with the required id.
  *
  * The returned #NAObjectId is owned by the @item object ; the
  * caller should not try to g_free() nor g_object_unref() it.
+ *
+ * Since: 2.30
  */
 NAObjectId *
 na_object_item_get_item( const NAObjectItem *item, const gchar *id )
@@ -403,29 +426,31 @@ na_object_item_get_item( const NAObjectItem *item, const gchar *id )
 
 /**
  * na_object_item_get_position:
- * @object: this #NAObjectItem object.
- * @child: a #NAObjectId-derived child.
+ * @item: this #NAObjectItem object.
+ * @child: a #NAObjectId -derived child.
  *
- * Returns: the position of @child in the subitems list of @object,
+ * Returns: the position of @child in the subitems list of @item,
  * starting from zero, or -1 if not found.
+ *
+ * Since: 2.30
  */
 gint
-na_object_item_get_position( const NAObjectItem *object, const NAObjectId *child )
+na_object_item_get_position( const NAObjectItem *item, const NAObjectId *child )
 {
 	gint pos = -1;
-	GList *childs;
+	GList *children;
 
-	g_return_val_if_fail( NA_IS_OBJECT_ITEM( object ), pos );
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), pos );
 	g_return_val_if_fail( NA_IS_OBJECT_ID( child ), pos );
 
 	if( !child ){
 		return( pos );
 	}
 
-	if( !object->private->dispose_has_run ){
+	if( !item->private->dispose_has_run ){
 
-		childs = na_object_get_items( object );
-		pos = g_list_index( childs, ( gconstpointer ) child );
+		children = na_object_get_items( item );
+		pos = g_list_index( children, ( gconstpointer ) child );
 	}
 
 	return( pos );
@@ -440,6 +465,8 @@ na_object_item_get_position( const NAObjectItem *object, const NAObjectId *child
  * and setup the parent pointer of the child to its new parent.
  *
  * Doesn't modify the reference count on @object.
+ *
+ * Since: 2.30
  */
 void
 na_object_item_append_item( NAObjectItem *item, const NAObjectId *child )
@@ -465,37 +492,39 @@ na_object_item_append_item( NAObjectItem *item, const NAObjectId *child )
 /**
  * na_object_item_insert_at:
  * @item: the #NAObjectItem in which add the subitem.
- * @object: a #NAObjectId-derived to be inserted in the list of subitems.
- * @pos: the position at which the @object child should be inserted.
+ * @child: a #NAObjectId -derived to be inserted in the list of subitems.
+ * @pos: the position at which the @child should be inserted.
  *
- * Inserts a new @object in the list of subitems of @item.
+ * Inserts a new @child in the list of subitems of @item.
  *
- * Doesn't modify the reference count on @object.
+ * Doesn't modify the reference count on @child.
+ *
+ * Since: 2.30
  */
 void
-na_object_item_insert_at( NAObjectItem *item, const NAObjectId *object, gint pos )
+na_object_item_insert_at( NAObjectItem *item, const NAObjectId *child, gint pos )
 {
-	GList *childs, *it;
+	GList *children, *it;
 	gint i;
 
 	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
-	g_return_if_fail( NA_IS_OBJECT_ID( object ));
+	g_return_if_fail( NA_IS_OBJECT_ID( child ));
 
 	if( !item->private->dispose_has_run ){
 
-		childs = na_object_get_items( item );
-		if( pos == -1 || pos >= g_list_length( childs )){
-			na_object_append_item( item, object );
+		children = na_object_get_items( item );
+		if( pos == -1 || pos >= g_list_length( children )){
+			na_object_append_item( item, child );
 
 		} else {
 			i = 0;
-			for( it = childs ; it && i <= pos ; it = it->next ){
+			for( it = children ; it && i <= pos ; it = it->next ){
 				if( i == pos ){
-					childs = g_list_insert_before( childs, it, ( gpointer ) object );
+					children = g_list_insert_before( children, it, ( gpointer ) child );
 				}
 				i += 1;
 			}
-			na_object_set_items( item, childs );
+			na_object_set_items( item, children );
 		}
 	}
 }
@@ -503,41 +532,43 @@ na_object_item_insert_at( NAObjectItem *item, const NAObjectId *object, gint pos
 /**
  * na_object_item_insert_item:
  * @item: the #NAObjectItem to which add the subitem.
- * @object: a #NAObject to be inserted in the list of subitems.
- * @before: the #NAObject before which the @object should be inserted.
+ * @child: a #NAObjectId to be inserted in the list of subitems.
+ * @before: the #NAObjectId before which the @child should be inserted.
  *
- * Inserts a new @object in the list of subitems of @item.
+ * Inserts a new @child in the list of subitems of @item.
  *
- * Doesn't modify the reference count on @object.
+ * Doesn't modify the reference count on @child.
+ *
+ * Since: 2.30
  */
 void
-na_object_item_insert_item( NAObjectItem *item, const NAObject *object, const NAObject *before )
+na_object_item_insert_item( NAObjectItem *item, const NAObjectId *child, const NAObjectId *before )
 {
-	GList *childs;
+	GList *children;
 	GList *before_list;
 
 	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
-	g_return_if_fail( NA_IS_OBJECT( object ));
-	g_return_if_fail( !before || NA_IS_OBJECT( before ));
+	g_return_if_fail( NA_IS_OBJECT_ID( child ));
+	g_return_if_fail( !before || NA_IS_OBJECT_ID( before ));
 
 	if( !item->private->dispose_has_run ){
 
-		childs = na_object_get_items( item );
-		if( !g_list_find( childs, ( gpointer ) object )){
+		children = na_object_get_items( item );
+		if( !g_list_find( children, ( gpointer ) child )){
 
 			before_list = NULL;
 
 			if( before ){
-				before_list = g_list_find( childs, ( gconstpointer ) before );
+				before_list = g_list_find( children, ( gconstpointer ) before );
 			}
 
 			if( before_list ){
-				childs = g_list_insert_before( childs, before_list, ( gpointer ) object );
+				children = g_list_insert_before( children, before_list, ( gpointer ) child );
 			} else {
-				childs = g_list_prepend( childs, ( gpointer ) object );
+				children = g_list_prepend( children, ( gpointer ) child );
 			}
 
-			na_object_set_items( item, childs );
+			na_object_set_items( item, children );
 		}
 	}
 }
@@ -545,19 +576,21 @@ na_object_item_insert_item( NAObjectItem *item, const NAObject *object, const NA
 /**
  * na_object_item_remove_item:
  * @item: the #NAObjectItem from which the subitem must be removed.
- * @object: a #NAObjectId-derived to be removed from the list of subitems.
+ * @child: a #NAObjectId -derived to be removed from the list of subitems.
  *
- * Removes an @object from the list of subitems of @item.
+ * Removes a @child from the list of subitems of @item.
  *
- * Doesn't modify the reference count on @object.
+ * Doesn't modify the reference count on @child.
+ *
+ * Since: 2.30
  */
 void
-na_object_item_remove_item( NAObjectItem *item, const NAObjectId *object )
+na_object_item_remove_item( NAObjectItem *item, const NAObjectId *child )
 {
 	GList *children;
 
 	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
-	g_return_if_fail( NA_IS_OBJECT_ID( object ));
+	g_return_if_fail( NA_IS_OBJECT_ID( child ));
 
 	if( !item->private->dispose_has_run ){
 
@@ -565,10 +598,10 @@ na_object_item_remove_item( NAObjectItem *item, const NAObjectId *object )
 
 		if( children ){
 			g_debug( "na_object_item_remove_item: removing %p (%s) from %p (%s)",
-					( void * ) object, G_OBJECT_TYPE_NAME( object ),
+					( void * ) child, G_OBJECT_TYPE_NAME( child ),
 					( void * ) item, G_OBJECT_TYPE_NAME( item ));
 
-			children = g_list_remove( children, ( gconstpointer ) object );
+			children = g_list_remove( children, ( gconstpointer ) child );
 			g_debug( "na_object_item_remove_item: after: children=%p, count=%u", ( void * ) children, g_list_length( children ));
 			na_object_set_items( item, children );
 		}
@@ -580,6 +613,8 @@ na_object_item_remove_item( NAObjectItem *item, const NAObjectId *object )
  * @item: the #NAObjectItem from which we want a count of subitems.
  *
  * Returns: the count of subitems of @item.
+ *
+ * Since: 2.30
  */
 guint
 na_object_item_get_items_count( const NAObjectItem *item )
@@ -601,17 +636,19 @@ na_object_item_get_items_count( const NAObjectItem *item )
 
 /**
  * na_object_item_count_items:
- * @items: a list if #NAObject-derived to be counted.
+ * @items: a list if #NAObject -derived to be counted.
  * @menus: will be set to the count of menus.
  * @actions: will be set to the count of actions.
  * @profiles: will be set to the count of profiles.
  * @recurse: whether to recursively count all items, or only those in
  *  level zero of the list.
  *
- * Count the numbers of items if the provided list.
+ * Returns: the count the numbers of items if the provided list.
  *
  * As this function is recursive, the counters should be initialized by
  * the caller before calling it.
+ *
+ * Since: 2.30
  */
 void
 na_object_item_count_items( GList *items, gint *menus, gint *actions, gint *profiles, gboolean recurse )
@@ -644,11 +681,13 @@ na_object_item_count_items( GList *items, gint *menus, gint *actions, gint *prof
 
 /**
  * na_object_item_unref_items:
- * @list: a list of #NAObject-derived items.
+ * @items: a list of #NAObject -derived items.
  *
  * Unref only the first level the #NAObject of the list, freeing the list at last.
  *
- * This is rather only used by #NAPivot.
+ * This is rather only used by NAPivot.
+ *
+ * Since: 2.30
  */
 void
 na_object_item_unref_items( GList *items )
@@ -659,11 +698,13 @@ na_object_item_unref_items( GList *items )
 
 /**
  * na_object_item_unref_items_rec:
- * @list: a list of #NAObject-derived items.
+ * @items: a list of #NAObject -derived items.
  *
- * Recursively unref the #NAObject of the list, freeing the list at last.
+ * Recursively unref the #NAObject's of the list, freeing the list at last.
  *
  * This is heavily used by NACT.
+ *
+ * Since: 2.30
  */
 void
 na_object_item_unref_items_rec( GList *items )
@@ -678,15 +719,79 @@ na_object_item_unref_items_rec( GList *items )
 }
 
 /**
- * na_object_item_factory_write_start:
- * @item: this #NAObjectItem-derived object.
+ * na_object_item_deals_with_version:
+ * @item: this #NAObjectItem -derived object.
  *
- * Rebuild the string list of children.
+ * Just after the @item has been readen from NAIFactoryProvider, setup
+ * the version. This is needed because some conversions may occur in
+ * this object.
+ *
+ * Note that there is only some 2.x versions where the version string
+ * was not systematically written. If @item has been readen from a
+ * .desktop file, then iversion is already set to (at least) 3.
+ *
+ * Since: 2.30
  */
 void
-na_object_item_factory_write_start( NAObjectItem *item )
+na_object_item_deals_with_version( NAObjectItem *item )
 {
-	rebuild_children_slist( item );
+	guint version_uint;
+	gchar *version_str;
+
+	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
+
+	if( !item->private->dispose_has_run ){
+
+		version_uint = na_object_get_iversion( item );
+
+		if( !version_uint ){
+			version_str = na_object_get_version( item );
+
+			if( !version_str || !strlen( version_str )){
+				g_free( version_str );
+				version_str = g_strdup( "2.0" );
+			}
+
+			version_uint = atoi( version_str );
+			na_object_set_iversion( item, version_uint );
+
+			g_free( version_str );
+		}
+	}
+}
+
+/**
+ * na_object_item_rebuild_children_slist:
+ * @item: this #NAObjectItem -derived object.
+ *
+ * Rebuild the string list of children.
+ *
+ * Since: 2.30
+ */
+void
+na_object_item_rebuild_children_slist( NAObjectItem *item )
+{
+	GSList *slist;
+	GList *subitems, *it;
+	gchar *id;
+
+	na_object_set_items_slist( item, NULL );
+
+	if( !item->private->dispose_has_run ){
+
+		subitems = na_object_get_items( item );
+		slist = NULL;
+
+		for( it = subitems ; it ; it = it->next ){
+			id = na_object_get_id( it->data );
+			slist = g_slist_prepend( slist, id );
+		}
+		slist = g_slist_reverse( slist );
+
+		na_object_set_items_slist( item, slist );
+
+		na_core_utils_slist_free( slist );
+	}
 }
 
 static void
@@ -714,28 +819,3 @@ copy_children( NAObjectItem *target, const NAObjectItem *source )
 	tgt_children = g_list_reverse( tgt_children );
 	na_object_set_items( target, tgt_children );
 }
-
-static void
-rebuild_children_slist( NAObjectItem *item )
-{
-	GSList *slist;
-	GList *subitems, *it;
-	gchar *id;
-
-	slist = NULL;
-
-	if( !item->private->dispose_has_run ){
-
-		subitems = na_object_get_items( item );
-
-		for( it = subitems ; it ; it = it->next ){
-			id = na_object_get_id( it->data );
-			slist = g_slist_prepend( slist, id );
-		}
-		slist = g_slist_reverse( slist );
-
-		na_object_set_items_slist( item, slist );
-
-		na_core_utils_slist_free( slist );
-	}
-}
