@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu modules.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,9 +31,8 @@
 #ifndef __CORE_NA_TOKENS_H__
 #define __CORE_NA_TOKENS_H__
 
-/**
- * SECTION: na_tokens
- * @short_description: #NATokens class definition.
+/* @title: NATokens
+ * @short_description: The #NATokens Class Definition
  * @include: core/na-tokens.h
  *
  * The #NATokens class manages the tokens which are to be replaced with
@@ -85,24 +84,26 @@
 
 G_BEGIN_DECLS
 
-#define NA_TOKENS_TYPE					( na_tokens_get_type())
-#define NA_TOKENS( object )				( G_TYPE_CHECK_INSTANCE_CAST( object, NA_TOKENS_TYPE, NATokens ))
-#define NA_TOKENS_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NA_TOKENS_TYPE, NATokensClass ))
-#define NA_IS_TOKENS( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_TOKENS_TYPE ))
-#define NA_IS_TOKENS_CLASS( klass )		( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_TOKENS_TYPE ))
-#define NA_TOKENS_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_TOKENS_TYPE, NATokensClass ))
+#define NA_TOKENS_TYPE                  ( na_tokens_get_type())
+#define NA_TOKENS( object )             ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_TOKENS_TYPE, NATokens ))
+#define NA_TOKENS_CLASS( klass )        ( G_TYPE_CHECK_CLASS_CAST( klass, NA_TOKENS_TYPE, NATokensClass ))
+#define NA_IS_TOKENS( object )          ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_TOKENS_TYPE ))
+#define NA_IS_TOKENS_CLASS( klass )     ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_TOKENS_TYPE ))
+#define NA_TOKENS_GET_CLASS( object )   ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_TOKENS_TYPE, NATokensClass ))
 
-typedef struct NATokensPrivate      NATokensPrivate;
+typedef struct _NATokensPrivate      NATokensPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObject          parent;
 	NATokensPrivate *private;
 }
 	NATokens;
 
-typedef struct NATokensClassPrivate NATokensClassPrivate;
+typedef struct _NATokensClassPrivate NATokensClassPrivate;
 
 typedef struct {
+	/*< private >*/
 	GObjectClass          parent;
 	NATokensClassPrivate *private;
 }
