@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -74,10 +74,13 @@ typedef struct {
 
 GType            nadp_desktop_file_get_type         ( void );
 
+NadpDesktopFile *nadp_desktop_file_new              ( void );
 NadpDesktopFile *nadp_desktop_file_new_from_path    ( const gchar *path );
+NadpDesktopFile *nadp_desktop_file_new_from_uri     ( const gchar *uri );
 NadpDesktopFile *nadp_desktop_file_new_for_write    ( const gchar *path );
 
-gchar           *nadp_desktop_file_get_key_file_path( const NadpDesktopFile *ndf );
+GKeyFile        *nadp_desktop_file_get_key_file     ( const NadpDesktopFile *ndf );
+gchar           *nadp_desktop_file_get_key_file_uri ( const NadpDesktopFile *ndf );
 gboolean         nadp_desktop_file_write            ( NadpDesktopFile *ndf );
 
 gchar           *nadp_desktop_file_get_file_type    ( const NadpDesktopFile *ndf );
@@ -85,6 +88,7 @@ gchar           *nadp_desktop_file_get_id           ( const NadpDesktopFile *ndf
 GSList          *nadp_desktop_file_get_profiles     ( const NadpDesktopFile *ndf );
 
 void             nadp_desktop_file_remove_key       ( const NadpDesktopFile *ndf, const gchar *group, const gchar *key );
+void             nadp_desktop_file_remove_profile   ( const NadpDesktopFile *ndf, const gchar *profile_id );
 
 gboolean         nadp_desktop_file_get_boolean      ( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, gboolean *key_found, gboolean default_value );
 gchar           *nadp_desktop_file_get_locale_string( const NadpDesktopFile *ndf, const gchar *group, const gchar *key, gboolean *key_found, const gchar *default_value );
