@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -52,8 +52,7 @@ struct NagpGConfProviderClassPrivate {
 
 static GType         st_module_type = 0;
 static GObjectClass *st_parent_class = NULL;
-static gint          st_timeout_msec = 100;
-static gint          st_timeout_usec = 100000;
+static gint          st_burst_timeout = 100;		/* burst timeout in msec */
 
 static void     class_init( NagpGConfProviderClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
@@ -70,11 +69,8 @@ static guint    ifactory_provider_get_version( const NAIFactoryProvider *provide
 
 static GList   *install_monitors( NagpGConfProvider *provider );
 static void     config_path_changed_cb( GConfClient *client, guint cnxn_id, GConfEntry *entry, NagpGConfProvider *provider );
-static void     config_path_changed_reset_timeout( NagpGConfProvider *provider );
-static void     config_path_changed_set_timeout( NagpGConfProvider *provider, const gchar *uuid );
 static gboolean config_path_changed_trigger_interface( NagpGConfProvider *provider );
 static gulong   time_val_diff( const GTimeVal *recent, const GTimeVal *old );
-static gchar   *entry2uuid( GConfEntry *entry );
 
 GType
 nagp_gconf_provider_get_type( void )
@@ -214,6 +210,7 @@ iio_provider_iface_init( NAIIOProviderInterface *iface )
 	iface->is_able_to_write = nagp_iio_provider_is_able_to_write;
 	iface->write_item = nagp_iio_provider_write_item;
 	iface->delete_item = nagp_iio_provider_delete_item;
+	iface->duplicate_data = NULL;
 }
 
 static gchar *
@@ -242,7 +239,7 @@ ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
 	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
 
 	iface->get_version = ifactory_provider_get_version;
-	iface->read_start = NULL;
+	iface->read_start = nagp_reader_read_start;
 	iface->read_data = nagp_reader_read_data;
 	iface->read_done = nagp_reader_read_done;
 	iface->write_start = nagp_writer_write_start;
@@ -310,101 +307,68 @@ install_monitors( NagpGConfProvider *provider )
  * - first, GConf underlying subsystem advertises us, through the watch
  *   mechanism, of each and every modification ; this leads us to be
  *   triggered for each new/modified/deleted _entry_
- * - as we would trigger the NAIIOProvider interface only once for each
- *   modified _object_, we install a timer in order to wait for all
- *   entries have been modified, or another object is concerned
- * - as soon as one of the two previous conditions is met, we trigger
- *   the NAIIOProvider interface with the corresponding object id
+ * - as we want trigger the NAIIOProvider interface only once for each
+ *   update operation (i.e. once for each flow of individual notifications),
+ *   then we install a timer in order to wait for all
+ *   entries have been modified
+ * - when a [burst_timeout] reasonable delay has elapsed without having
+ *   received any new individual notification, then we can assume that
+ *   we have reached the end of the flow and that we can now trigger
+ *   the NAIIOProvider interface
+ *
+ * Note that we used to try to send one notification per modified object.
+ * This cannot work as we are not sure at all that we will received
+ * individual notifications themselves grouped by object.
  */
 static void
 config_path_changed_cb( GConfClient *client, guint cnxn_id, GConfEntry *entry, NagpGConfProvider *provider )
 {
-	/*static const gchar *thisfn = "nagp_gconf_provider_config_path_changed_cb";*/
-	gchar *uuid;
-
-	/*g_debug( "%s: client=%p, cnxnid=%u, entry=%p, provider=%p",
-			thisfn, ( void * ) client, cnxn_id, ( void * ) entry, ( void * ) provider );*/
-
 	g_return_if_fail( NAGP_IS_GCONF_PROVIDER( provider ));
 	g_return_if_fail( NA_IS_IIO_PROVIDER( provider ));
 
 	if( !provider->private->dispose_has_run ){
 
-		uuid = entry2uuid( entry );
-		/*g_debug( "%s: uuid=%s", thisfn, uuid );*/
+		g_get_current_time( &provider->private->last_event );
 
-		if( provider->private->event_source_id ){
-			if( g_ascii_strcasecmp( uuid, provider->private->last_triggered_id )){
-
-				/* there already has a timeout, but on another object
-				 * so trigger the interface for the previous object
-				 * and set the timeout for the new object
-				 */
-				config_path_changed_trigger_interface( provider );
-				config_path_changed_set_timeout( provider, uuid );
-			}
-
-			/* there already has a timeout for this same object
-			 * do nothing
-			 */
-
-		} else {
-			/* there was not yet any timeout: set it
-			 */
-			config_path_changed_set_timeout( provider, uuid );
+		if( !provider->private->event_source_id ){
+			provider->private->event_source_id =
+				g_timeout_add(
+						st_burst_timeout,
+						( GSourceFunc ) config_path_changed_trigger_interface,
+						provider );
 		}
-
-		g_free( uuid );
 	}
 }
 
-static void
-config_path_changed_reset_timeout( NagpGConfProvider *provider )
-{
-	g_free( provider->private->last_triggered_id );
-	provider->private->last_triggered_id = NULL;
-	/*provider->private->last_event = ( GTimeVal ) 0;*/
-	provider->private->event_source_id = 0;
-}
-
-static void
-config_path_changed_set_timeout( NagpGConfProvider *provider, const gchar *uuid )
-{
-	config_path_changed_reset_timeout( provider );
-	provider->private->last_triggered_id = g_strdup( uuid );
-	g_get_current_time( &provider->private->last_event );
-	provider->private->event_source_id =
-		g_timeout_add(
-				st_timeout_msec,
-				( GSourceFunc ) config_path_changed_trigger_interface,
-				provider );
-}
-
 /*
  * this timer is set when we receive the first event of a serie
- * we continue to loop until last event is at least one half of a
- * second old
+ * we continue to loop until last event is older that the st_burst_timeout
+ * delay (in msec)
  * there is no race condition here as we are not multithreaded
  * or .. is there ?
  */
 static gboolean
 config_path_changed_trigger_interface( NagpGConfProvider *provider )
 {
-	/*static const gchar *thisfn = "nagp_gconf_provider_config_path_changed_trigger_interface";*/
+	static const gchar *thisfn = "nagp_gconf_provider_config_path_changed_trigger_interface";
 	GTimeVal now;
 	gulong diff;
-
-	/*g_debug( "%s: provider=%p", thisfn, ( void * ) provider );*/
+	gulong timeout_usec = 1000*st_burst_timeout;
 
 	g_get_current_time( &now );
 	diff = time_val_diff( &now, &provider->private->last_event );
-	if( diff < st_timeout_usec ){
+	if( diff < timeout_usec ){
 		return( TRUE );
 	}
 
-	na_iio_provider_item_changed( NA_IIO_PROVIDER( provider ), provider->private->last_triggered_id );
+	/* last individual notification is older that the st_burst_timeout
+	 * so triggers the NAIIOProvider interface and destroys this timeout
+	 */
+	g_debug( "%s: triggering NAIIOProvider interface for provider=%p (%s)",
+			thisfn, ( void * ) provider, G_OBJECT_TYPE_NAME( provider ));
 
-	config_path_changed_reset_timeout( provider );
+	na_iio_provider_item_changed( NA_IIO_PROVIDER( provider ));
+	provider->private->event_source_id = 0;
 	return( FALSE );
 }
 
@@ -418,26 +382,3 @@ time_val_diff( const GTimeVal *recent, const GTimeVal *old )
 	microsec += recent->tv_usec  - old->tv_usec;
 	return( microsec );
 }
-
-/*
- * gets the uuid from an entry
- */
-static gchar *
-entry2uuid( GConfEntry *entry )
-{
-	const gchar *path;
-	const gchar *subpath;
-	gchar **split;
-	gchar *uuid;
-
-	g_return_val_if_fail( entry, NULL );
-
-	path = gconf_entry_get_key( entry );
-	subpath = path + strlen( NAGP_CONFIGURATIONS_PATH ) + 1;
-	split = g_strsplit( subpath, "/", -1 );
-	/*g_debug( "%s: [0]=%s, [1]=%s", thisfn, split[0], split[1] );*/
-	uuid = g_strdup( split[0] );
-	g_strfreev( split );
-
-	return( uuid );
-}
