@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -46,6 +46,9 @@
 #include "nagp-writer.h"
 #include "nagp-keys.h"
 
+static void write_start_write_type( NagpGConfProvider *provider, NAObjectItem *item );
+static void write_start_write_version( NagpGConfProvider *provider, NAObjectItem *item );
+
 /*
  * API function: should only be called through NAIIOProvider interface
  */
@@ -69,7 +72,7 @@ nagp_iio_provider_is_willing_to_write( const NAIIOProvider *provider )
 gboolean
 nagp_iio_provider_is_able_to_write( const NAIIOProvider *provider )
 {
-	/*static const gchar *thisfn = "nagp_iio_provider_is_able_to_write";*/
+	static const gchar *thisfn = "nagp_iio_provider_is_able_to_write";
 	static const gchar *path = "/apps/nautilus-actions/foo";
 	NagpGConfProvider *self;
 	gboolean able_to = FALSE;
@@ -82,18 +85,28 @@ nagp_iio_provider_is_able_to_write( const NAIIOProvider *provider )
 
 	if( !self->private->dispose_has_run ){
 
-		if( !na_gconf_utils_write_string( self->private->gconf, path, "1", NULL )){
-			able_to = FALSE;
-
-		} else if( !gconf_client_recursive_unset( self->private->gconf, path, 0, NULL )){
+		if( !na_gconf_utils_write_string( self->private->gconf, path, "foo", NULL )){
 			able_to = FALSE;
 
 		} else {
-			able_to = TRUE;
+			gchar *str = na_gconf_utils_read_string( self->private->gconf, path, FALSE, NULL );
+			if( strcmp( str, "foo" )){
+				able_to = FALSE;
+
+			} else if( !gconf_client_recursive_unset( self->private->gconf, path, 0, NULL )){
+				able_to = FALSE;
+
+			} else {
+				able_to = TRUE;
+			}
+
+			g_free( str );
 		}
 	}
 
-	/*g_debug( "%s: provider=%p, able_to=%s", thisfn, ( void * ) provider, able_to ? "True":"False" );*/
+	gconf_client_suggest_sync( self->private->gconf, NULL );
+
+	g_debug( "%s: provider=%p, able_to=%s", thisfn, ( void * ) provider, able_to ? "True":"False" );
 	return( able_to );
 }
 
@@ -213,24 +226,48 @@ guint
 nagp_writer_write_start( const NAIFactoryProvider *writer, void *writer_data,
 							const NAIFactoryObject *object, GSList **messages  )
 {
-	GConfClient *gconf;
-	gchar *id;
-	gchar *path;
-
 	if( NA_IS_OBJECT_ITEM( object )){
-		id = na_object_get_id( object );
-		path = g_strdup_printf( "%s/%s/%s", NAGP_CONFIGURATIONS_PATH, id, NAGP_ENTRY_TYPE );
-		gconf = NAGP_GCONF_PROVIDER( writer )->private->gconf;
-
-		na_gconf_utils_write_string( gconf, path, NA_IS_OBJECT_ACTION( object ) ? NAGP_VALUE_TYPE_ACTION : NAGP_VALUE_TYPE_MENU, NULL );
-
-		g_free( path );
-		g_free( id );
+		write_start_write_type( NAGP_GCONF_PROVIDER( writer ), NA_OBJECT_ITEM( object ));
+		write_start_write_version( NAGP_GCONF_PROVIDER( writer ), NA_OBJECT_ITEM( object ));
 	}
 
 	return( NA_IIO_PROVIDER_CODE_OK );
 }
 
+static void
+write_start_write_type( NagpGConfProvider *provider, NAObjectItem *item )
+{
+	gchar *id, *path;
+
+	id = na_object_get_id( item );
+	path = g_strdup_printf( "%s/%s/%s", NAGP_CONFIGURATIONS_PATH, id, NAGP_ENTRY_TYPE );
+
+	na_gconf_utils_write_string(
+			provider->private->gconf,
+			path,
+			NA_IS_OBJECT_ACTION( item ) ? NAGP_VALUE_TYPE_ACTION : NAGP_VALUE_TYPE_MENU,
+			NULL );
+
+	g_free( path );
+	g_free( id );
+}
+
+static void
+write_start_write_version( NagpGConfProvider *provider, NAObjectItem *item )
+{
+	gchar *id, *path;
+	guint iversion;
+
+	id = na_object_get_id( item );
+	path = g_strdup_printf( "%s/%s/%s", NAGP_CONFIGURATIONS_PATH, id, NAGP_ENTRY_IVERSION );
+
+	iversion = na_object_get_iversion( item );
+	na_gconf_utils_write_int( provider->private->gconf, path, iversion, NULL );
+
+	g_free( path );
+	g_free( id );
+}
+
 guint
 nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 									const NAIFactoryObject *object, const NADataBoxed *boxed,
@@ -252,9 +289,9 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
 
 	msg = NULL;
 	code = NA_IIO_PROVIDER_CODE_OK;
+	def = na_data_boxed_get_data_def( boxed );
 
-	if( na_data_boxed_is_set( boxed )){
-		def = na_data_boxed_get_data_def( boxed );
+	if( !na_data_boxed_is_default( boxed ) || def->write_if_default ){
 
 		if( NA_IS_OBJECT_PROFILE( object )){
 			NAObjectItem *parent = NA_OBJECT_ITEM( na_object_get_parent( object ));
