@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -515,7 +515,7 @@ assist_runtime_init_target_folder( NactAssistantExport *window, GtkAssistant *as
 
 	uri = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_EXPORT_ITEMS_FOLDER_URI, "file:///tmp" );
 	if( uri && strlen( uri )){
-		gtk_file_chooser_set_uri( GTK_FILE_CHOOSER( chooser ), uri );
+		gtk_file_chooser_set_current_folder_uri( GTK_FILE_CHOOSER( chooser ), uri );
 	}
 	g_free( uri );
 
@@ -559,7 +559,7 @@ on_folder_selection_changed( GtkFileChooser *chooser, gpointer user_data )
 	pos = gtk_assistant_get_current_page( assistant );
 	if( pos == ASSIST_PAGE_FOLDER_SELECTION ){
 
-		uri = gtk_file_chooser_get_uri( chooser );
+		uri = gtk_file_chooser_get_current_folder_uri( chooser );
 		g_debug( "%s: uri=%s", thisfn, uri );
 		enabled = ( uri && strlen( uri ) && na_core_utils_dir_is_writable_uri( uri ));
 
@@ -772,14 +772,19 @@ assist_prepare_exportdone( NactAssistantExport *window, GtkAssistant *assistant,
 	gchar *label;
 	GSList *is;
 	gint errors;
-	GtkLabel *summary_label;
+	GtkTextView *summary_textview;
+	GtkTextBuffer *summary_buffer;
+	GtkTextTag *title_tag;
+	GtkTextIter start, end;
+	gint title_len;
 
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
 	/* i18n: result of the export assistant */
 	text = g_strdup( _( "Selected actions have been proceeded :" ));
-	tmp = g_strdup_printf( "<b>%s</b>\n\n", text );
+	title_len = g_utf8_strlen( text, -1 );
+	tmp = g_strdup_printf( "%s\n\n", text );
 	g_free( text );
 	text = tmp;
 
@@ -824,10 +829,21 @@ assist_prepare_exportdone( NactAssistantExport *window, GtkAssistant *assistant,
 		text = tmp;
 	}
 
-	summary_label = GTK_LABEL( base_window_get_widget( BASE_WINDOW( window ), "AssistantExportSummaryLabel" ));
-	gtk_label_set_markup( summary_label, text );
+	summary_textview = GTK_TEXT_VIEW( base_window_get_widget( BASE_WINDOW( window ), "AssistantExportSummaryTextView" ));
+	summary_buffer = gtk_text_view_get_buffer( summary_textview );
+	gtk_text_buffer_set_text( summary_buffer, text, -1 );
 	g_free( text );
 
+	title_tag = gtk_text_buffer_create_tag( summary_buffer, "title",
+			"weight", PANGO_WEIGHT_BOLD,
+			NULL );
+
+	gtk_text_buffer_get_iter_at_offset( summary_buffer, &start, 0 );
+	gtk_text_buffer_get_iter_at_offset( summary_buffer, &end, title_len );
+	gtk_text_buffer_apply_tag( summary_buffer, title_tag, &start, &end );
+
+	g_object_unref( title_tag );
+
 	gtk_assistant_set_page_complete( assistant, page, TRUE );
 	base_assistant_set_warn_on_cancel( BASE_ASSISTANT( window ), FALSE );
 	base_assistant_set_warn_on_esc( BASE_ASSISTANT( window ), FALSE );
