@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -52,7 +52,7 @@
 
 #include <gtk/gtk.h>
 
-#include <runtime/na-object-class.h>
+#include <api/na-object-item.h>
 
 G_BEGIN_DECLS
 
@@ -69,23 +69,6 @@ typedef struct {
 	GTypeInterface                    parent;
 	NactIActionsListInterfacePrivate *private;
 
-	/**
-	 * selection_changed:
-	 * @instance: this #NactIActionsList implementor.
-	 * @selected_items: currently selected items.
-	 *
-	 * This function is an exact duplicate of the
-	 * "nact-iactions-list-selection-changed" signal. Implementor may
-	 * choose to to connect to the signal, or to implement this api, in
-	 * order to be triggered when the selection is modified in the
-	 * treeview.
-	 *
-	 * Be warned that both implementing the api and connecting to the
-	 * signal must be considered at least as useless, and just a way to
-	 * be triggered twice for the same event.
-	 */
-	void    ( *selection_changed )( NactIActionsList *instance, GSList *selected_items );
-
 	/**
 	 * get_treeview_name:
 	 * @instance: this #NactIActionsList implementor.
@@ -128,23 +111,31 @@ void      nact_iactions_list_dispose( NactIActionsList *instance );
 
 void      nact_iactions_list_brief_tree_dump( NactIActionsList *instance );
 void      nact_iactions_list_collapse_all( NactIActionsList *instance );
-void      nact_iactions_list_delete( NactIActionsList *instance, GList *items );
 void      nact_iactions_list_display_order_change( NactIActionsList *instance, gint order_mode );
 void      nact_iactions_list_expand_all( NactIActionsList *instance );
 void      nact_iactions_list_fill( NactIActionsList *instance, GList *items );
-NAObject *nact_iactions_list_get_item( NactIActionsList *instance, const gchar *uuid );
-GList    *nact_iactions_list_get_items( NactIActionsList *instance );
 gint      nact_iactions_list_get_management_mode( NactIActionsList *instance );
-GList    *nact_iactions_list_get_selected_items( NactIActionsList *instance );
-gboolean  nact_iactions_list_has_focus( NactIActionsList *instance );
 gboolean  nact_iactions_list_has_modified_items( NactIActionsList *instance );
-void      nact_iactions_list_insert_at_path( NactIActionsList *instance, GList *items, GtkTreePath *path );
-void      nact_iactions_list_insert_items( NactIActionsList *instance, GList *items, NAObject *sibling );
-void      nact_iactions_list_insert_into( NactIActionsList *instance, GList *items );
-gboolean  nact_iactions_list_is_expanded( NactIActionsList *instance, const NAObject *item );
-void      nact_iactions_list_removed_modified( NactIActionsList *instance );
+void      nact_iactions_list_on_treeview_selection_changed( GtkTreeSelection *selection, NactIActionsList *instance );
+GList    *nact_iactions_list_remove_rec( GList *list, NAObject *object );
 void      nact_iactions_list_set_management_mode( NactIActionsList *instance, gint mode );
-void      nact_iactions_list_toggle_collapse( NactIActionsList *instance, const NAObject *item );
+
+void      nact_iactions_list_bis_clear_selection( NactIActionsList *instance, GtkTreeView *treeview );
+void      nact_iactions_list_bis_collapse_to_parent( NactIActionsList *instance );
+void      nact_iactions_list_bis_delete( NactIActionsList *instance, GList *items, gboolean select_at_end );
+void      nact_iactions_list_bis_expand_to_first_child( NactIActionsList *instance );
+NAObject *nact_iactions_list_bis_get_item( NactIActionsList *instance, const gchar *uuid );
+GList    *nact_iactions_list_bis_get_items( NactIActionsList *instance );
+GList    *nact_iactions_list_bis_get_selected_items( NactIActionsList *instance );
+void      nact_iactions_list_bis_insert_at_path( NactIActionsList *instance, GList *items, GtkTreePath *path );
+void      nact_iactions_list_bis_insert_items( NactIActionsList *instance, GList *items, NAObject *sibling );
+void      nact_iactions_list_bis_insert_into( NactIActionsList *instance, GList *items );
+void      nact_iactions_list_bis_list_modified_items( NactIActionsList *instance );
+void      nact_iactions_list_bis_remove_modified( NactIActionsList *instance, const NAObjectItem *item );
+void      nact_iactions_list_bis_select_first_row( NactIActionsList *instance );
+void      nact_iactions_list_bis_select_row_at_path( NactIActionsList *instance, GtkTreeView *treeview, GtkTreeModel *model, GtkTreePath *path );
+void      nact_iactions_list_bis_toggle_collapse( NactIActionsList *instance );
+void      nact_iactions_list_bis_toggle_collapse_object( NactIActionsList *instance, const NAObject *item );
 
 G_END_DECLS
 
