@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1364,7 +1364,7 @@ setup_dialog_title( NactMainWindow *window )
 
 	if( window->private->selected_item ){
 		label = na_object_get_label( window->private->selected_item );
-		tmp = g_strdup_printf( "%s - %s", title, label );
+		tmp = g_strdup_printf( "%s - %s", label, title );
 		g_free( label );
 		g_free( title );
 		title = tmp;
